/*
* MIT License
* 
* Copyright (c) 2022 nap.software
* 
* Permission is hereby granted, free of charge, to any person obtaining a copy
* of this software and associated documentation files (the "Software"), to deal
* in the Software without restriction, including without limitation the rights
* to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
* copies of the Software, and to permit persons to whom the Software is
* furnished to do so, subject to the following conditions:
* 
* The above copyright notice and this permission notice shall be included in all
* copies or substantial portions of the Software.
* 
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
* AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
* LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
* OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
* SOFTWARE.
*/
#if !defined(NAPC_HW_MODULE_ENV_h)
	#define NAPC_HW_MODULE_ENV_h

	#include <libnapc.h>

	/*!
	 * @name napc_env_isFileSystemAvailable
	 * @brief Check file system availability.
	 * @version 1.1.0
	 * @return Returns `true` if file system functionality is available.
	 * @changelog 1.1.0 18.03.2022 initial version
	 * @example
	 * if (napc_env_isFileSystemAvailable()) {
	 *     napc_printf("File System is available.\n");
	 * }
	 */
	bool napc_env_isFileSystemAvailable(void) NAPC_FN_WARNUNUSED_RET();

	/*!
	 * @name napc_env_isEthernetAvailable
	 * @brief Check ethernet availability.
	 * @version 1.1.0
	 * @return Returns `true` if ethernet functionality is available.
	 * @changelog 1.1.0 18.03.2022 initial version
	 * @example
	 * if (napc_env_isEthernetAvailable()) {
	 *     napc_printf("Ethernet is available.\n");
	 * }
	 */
	bool napc_env_isEthernetAvailable(void) NAPC_FN_WARNUNUSED_RET();
#endif
